@@ -1,4 +1,7 @@
 #!/usr/bin/perl -w
+
+eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+    if 0; # not running under some shell
 #
 # Copyright (c) 2012 Jasper Lievisse Adriaanse <jasper@mtier.org>
 # Copyright (c) 2012 M:tier Ltd.
